@@ -2,11 +2,13 @@ from .errorHandler import UnauthorizedException, ForbiddenException, ApiExceptio
     ValidationException, InternalException, NotFoundException, TooManyRequestsException
 from typing_extensions import TypedDict
 from typing import Optional
-from ..metaApi.models import ExceptionMessage
+from ..metaApi.models import ExceptionMessage, date, format_error
+from .timeoutException import TimeoutException
 import json
 import asyncio
 import sys
 import httpx
+from datetime import datetime
 from httpx import HTTPError, Response
 
 
@@ -26,12 +28,13 @@ class RequestOptions(TypedDict):
 
 class HttpClient:
     """HTTP client library based on requests module."""
-    def __init__(self, timeout: float = 60, retry_opts=None):
+    def __init__(self, timeout: float = None, retry_opts=None):
         """Inits HttpClient class instance.
 
         Args:
             timeout: Request timeout in seconds.
         """
+        timeout = timeout or 60
         if retry_opts is None:
             retry_opts = {}
         self._timeout = timeout
@@ -39,8 +42,8 @@ class HttpClient:
         self._minRetryDelayInSeconds = retry_opts['minDelayInSeconds'] if 'minDelayInSeconds' in retry_opts else 1
         self._maxRetryDelayInSeconds = retry_opts['maxDelayInSeconds'] if 'maxDelayInSeconds' in retry_opts else 30
 
-    async def request(self, options: RequestOptions, retry_counter: int = 0) -> Response:
-        """Performs a request. Response errors are returned as ApiError or subclasses.
+    async def request(self, options: RequestOptions, retry_counter: int = 0, end_time: float = None) -> Response:
+        """Performs a request. Response errors are returned as ApiException or subclasses.
 
         Args:
             options: Request options.
@@ -48,26 +51,27 @@ class HttpClient:
         Returns:
             A request response.
         """
+        if not end_time:
+            end_time = datetime.now().timestamp() + self._maxRetryDelayInSeconds * self._retries
+        retry_after_seconds = 0
         try:
             response = await self._make_request(options)
             response.raise_for_status()
+            if response.status_code == 202:
+                retry_after_seconds = response.headers['retry-after']
+                if isinstance(retry_after_seconds, str):
+                    retry_after_seconds = float(retry_after_seconds)
             if response.content:
                 try:
                     response = response.json()
                 except Exception as err:
-                    print('Error parsing json', err)
+                    print('Error parsing json', format_error(err))
         except HTTPError as err:
-            if err.__class__.__name__ == 'ConnectTimeout':
-                error = err
-            else:
-                error = self._convert_error(err)
-            if error.__class__.__name__ in ['ConflictException', 'InternalException', 'ApiException', 'ConnectTimeout']\
-                    and retry_counter < self._retries:
-                await asyncio.sleep(min(pow(2, retry_counter) * self._minRetryDelayInSeconds,
-                                        self._maxRetryDelayInSeconds))
-                return await self.request(options, retry_counter + 1)
-            else:
-                raise error
+            retry_counter = await self._handle_error(err, retry_counter, end_time)
+            return await self.request(options, retry_counter, end_time)
+        if retry_after_seconds:
+            await self._handle_retry(end_time, retry_after_seconds)
+            response = await self.request(options, retry_counter, end_time)
         return response
 
     async def _make_request(self, options: RequestOptions) -> Response:
@@ -82,6 +86,29 @@ class HttpClient:
             response = await client.send(req)
             return response
 
+    async def _handle_retry(self, end_time: float, retry_after: float):
+        if end_time > datetime.now().timestamp() + retry_after:
+            await asyncio.sleep(retry_after)
+        else:
+            raise TimeoutException('Timed out waiting for the end of the process of calculating metrics')
+
+    async def _handle_error(self, err, retry_counter: int, end_time: float):
+        if err.__class__.__name__ == 'ConnectTimeout':
+            error = err
+        else:
+            error = self._convert_error(err)
+        if error.__class__.__name__ in ['ConflictException', 'InternalException', 'ApiException', 'ConnectTimeout']\
+                and retry_counter < self._retries:
+            pause = min(pow(2, retry_counter) * self._minRetryDelayInSeconds, self._maxRetryDelayInSeconds)
+            await asyncio.sleep(pause)
+            return retry_counter + 1
+        elif error.__class__.__name__ == 'TooManyRequestsException':
+            retry_time = date(error.metadata['recommendedRetryTime']).timestamp()
+            if retry_time < end_time:
+                await asyncio.sleep(retry_time - datetime.now().timestamp())
+                return retry_counter
+        raise error
+
     def _convert_error(self, err: HTTPError):
         try:
             response: ExceptionMessage or TypedDict = json.loads(err.response.text)
