@@ -2,7 +2,7 @@ from .memoryHistoryStorageModel import MemoryHistoryStorageModel
 import json
 import os
 import asyncio
-from .models import format_date, convert_iso_time_to_date
+from .models import format_date, convert_iso_time_to_date, format_error
 from typing import List
 from datetime import datetime
 from copy import deepcopy
@@ -95,7 +95,7 @@ class HistoryFileManager:
                 history['lastHistoryOrderTimeByInstanceIndex'] = config['lastHistoryOrderTimeByInstanceIndex']
         except Exception as err:
             print(f'[{datetime.now().isoformat()}] Failed to read history storage config of '
-                  f'account {self._accountId}', err)
+                  f'account {self._accountId}', format_error(err))
             os.remove(f'.metaapi/{self._accountId}-{self._application}-config.bin')
 
         try:
@@ -107,7 +107,7 @@ class HistoryFileManager:
                 history['deals'] = deals
         except Exception as err:
             print(f'[{datetime.now().isoformat()}] Failed to read deals history storage of '
-                  f'account {self._accountId}', err)
+                  f'account {self._accountId}', format_error(err))
             os.remove(f'.metaapi/{self._accountId}-{self._application}-deals.bin')
 
         try:
@@ -120,7 +120,7 @@ class HistoryFileManager:
                 history['historyOrders'] = history_orders
         except Exception as err:
             print(f'[{datetime.now().isoformat()}] Failed to read historyOrders history storage of '
-                  f'account {self._accountId}', err)
+                  f'account {self._accountId}', format_error(err))
             os.remove(f'.metaapi/{self._accountId}-{self._application}-historyOrders.bin')
         return history
 
@@ -167,7 +167,7 @@ class HistoryFileManager:
                             f.close()
                         except Exception as err:
                             print(f'[{datetime.now().isoformat()}] Error saving deals on disk for account '
-                                  f'{self._accountId}', err)
+                                  f'{self._accountId}', format_error(err))
                         self._dealsSize = list(map(self.get_item_size,
                                                    self._prepare_save_data(self._historyStorage.deals)))
                     else:
@@ -184,7 +184,7 @@ class HistoryFileManager:
                             f.close()
                         except Exception as err:
                             print(f'[{datetime.now().isoformat()}] Error saving historyOrders on disk for '
-                                  f'account {account_id}', err)
+                                  f'account {account_id}', format_error(err))
                         self._historyOrdersSize = list(map(
                             self.get_item_size, self._prepare_save_data(self._historyStorage.history_orders)))
                     else:
@@ -194,7 +194,7 @@ class HistoryFileManager:
                     self._startNewOrderIndex = -1
             except Exception as err:
                 print(f'[{datetime.now().isoformat()}] Error updating disk storage for '
-                      f'account {account_id}', err)
+                      f'account {account_id}', format_error(err))
             self._isUpdating = False
 
     async def _update_config(self):
@@ -212,7 +212,7 @@ class HistoryFileManager:
             f.close()
         except Exception as err:
             print(f'[{datetime.now().isoformat()}] Error updating disk storage config for '
-                  f'account {account_id}', err)
+                  f'account {account_id}', format_error(err))
 
     async def delete_storage_from_disk(self):
         """Deletes storage files from disk.
