@@ -166,6 +166,47 @@ class MetatraderAccount(MetatraderAccountModel):
         """
         return self._data['metadata'] if 'metadata' in self._data else None
 
+    @property
+    def tags(self) -> List[str]:
+        """Returns user-defined account tags.
+
+        Returns:
+            User-defined account tag.
+        """
+        return self._data['tags'] if 'tags' in self._data else None
+
+    @property
+    def copy_factory_roles(self) -> List[str]:
+        """Returns account roles for CopyFactory2 application.
+
+        Returns:
+            Account roles for CopyFactory2 application.
+        """
+        return self._data['copyFactoryRoles'] if 'copyFactoryRoles' in self._data else None
+
+    @property
+    def resource_slots(self) -> int:
+        """Returns number of resource slots to allocate to account. Allocating extra resource slots
+        results in better account performance under load which is useful for some applications. E.g. if you have many
+        accounts copying the same strategy via CopyFactory API, then you can increase resourceSlots to get a lower
+        trade copying latency. Please note that allocating extra resource slots is a paid option. Default is 1
+
+        Returns:
+            Number of resource slots to allocate to account.
+        """
+        return self._data['resourceSlots'] if 'resourceSlots' in self._data else None
+
+    @property
+    def base_currency(self) -> str:
+        """Returns 3-character ISO currency code of the account base currency. Default value is USD. The setting is to
+        be used for copy trading accounts which use national currencies only, such as some Brazilian brokers. You
+        should not alter this setting unless you understand what you are doing.
+
+        Returns:
+            3-character ISO currency code of the account base currency.
+        """
+        return self._data['baseCurrency'] if 'baseCurrency' in self._data else None
+
     @property
     def reliability(self) -> str:
         """Returns reliability value. Possible values are regular and high.
